@@ -27,7 +27,8 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
+#include <nautilus-burn-drive.h>
 #include <gconf/gconf-client.h>
 #include <glade/glade-xml.h>
 #include <gtk/gtkwidget.h>
@@ -80,12 +81,12 @@ extern GtkListStore *track_store;
 /**
  * The device we are extracting from.
  */
-extern const char *device;
+extern NautilusBurnDrive *drive;
 
 /**
  * The root path to write files too
  */
-extern const char *base_path;
+extern const char *base_uri;
 
 /**
  * The pattern to expand when naming folders
@@ -119,6 +120,7 @@ extern gboolean autostart;
 #define GCONF_DEVICE GCONF_ROOT "/device"
 #define GCONF_EJECT GCONF_ROOT "/eject"
 #define GCONF_BASEPATH GCONF_ROOT "/base_path"
+#define GCONF_BASEURI GCONF_ROOT "/base_uri"
 #define GCONF_FILE_PATTERN GCONF_ROOT "/file_pattern"
 #define GCONF_PATH_PATTERN GCONF_ROOT "/path_pattern"
 #define GCONF_AUDIO_PROFILE GCONF_ROOT "/audio_profile"
